##  Linking Discovered Items to Fact Sheets
After you set up the integration, the discovery process identifies your SAP Build projects and lists them in the SAP Discovery Inbox. In the inbox, you can review the discovered items and link them to existing fact sheets, or you can create and link new fact sheets. For more information, refer to [SAP Discovery Inbox](https://help.sap.com/docs/leanix/ea/sap-landscape-discovery-inbox?locale=en-US&state=PRODUCTION&version=CLOUD "Discovered products, services, and extensions from your SAP landscape appear in the SAP discovery inbox. Learn how to create, link, and reject fact sheets related to discovered items.").
When you link an SAP Build project to an application fact sheet, the corresponding reference catalog items automatically link to that fact sheet. This linking ensures that catalog information is automatically synchronized and continuously updated in the linked fact sheets. It also keeps IT component and provider information current in their respective fact sheets.
The specific information that gets updated depends on the data fields you select for synchronization. For more details, refer to [Applications in the Reference Catalog](https://help.sap.com/docs/leanix/ea/applications-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "By using reference data for application fact sheets, you can increase standardization and data quality, as well as set relations to other fact sheets for best-practice modeling.") and [Applications in the Reference Catalog](https://help.sap.com/docs/leanix/ea/applications-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "By using reference data for application fact sheets, you can increase standardization and data quality, as well as set relations to other fact sheets for best-practice modeling.").
